@@ -108,6 +108,40 @@ class TestCore < TestInteractive
     assert_equal %w[3 2 5 6 8 7], fzf_output_lines
   end
 
+  def test_subword_forward
+    tmux.send_keys "#{FZF} --bind K:kill-subword,F:forward-subword -q 'foo bar foo-bar fooFooBar'", :Enter, :Home
+    tmux.until { |lines| assert_equal '> foo bar foo-bar fooFooBar', lines.last }
+
+    tmux.send_keys 'F', :Delete
+    tmux.until { |lines| assert_equal '> foobar foo-bar fooFooBar', lines.last }
+
+    tmux.send_keys 'K'
+    tmux.until { |lines| assert_equal '> foo foo-bar fooFooBar', lines.last }
+
+    tmux.send_keys 'F', 'K'
+    tmux.until { |lines| assert_equal '> foo foo fooFooBar', lines.last }
+
+    tmux.send_keys 'F', 'F', 'K'
+    tmux.until { |lines| assert_equal '> foo foo fooFoo', lines.last }
+  end
+
+  def test_subword_backward
+    tmux.send_keys "#{FZF} --bind K:backward-kill-subword,B:backward-subword -q 'foo bar foo-bar fooBar'", :Enter
+    tmux.until { |lines| assert_equal '> foo bar foo-bar fooBar', lines.last }
+
+    tmux.send_keys 'B', :BSpace
+    tmux.until { |lines| assert_equal '> foo bar foo-bar foBar', lines.last }
+
+    tmux.send_keys 'K'
+    tmux.until { |lines| assert_equal '> foo bar foo-bar Bar', lines.last }
+
+    tmux.send_keys 'B', :BSpace
+    tmux.until { |lines| assert_equal '> foo bar foobar Bar', lines.last }
+
+    tmux.send_keys 'B', 'B', :BSpace
+    tmux.until { |lines| assert_equal '> foobar foobar Bar', lines.last }
+  end
+
   def test_multi_max
     tmux.send_keys "seq 1 10 | #{FZF} -m 3 --bind A:select-all,T:toggle-all --preview 'echo [{+}]/{}'", :Enter
 
@@ -1648,6 +1682,7 @@ class TestCore < TestInteractive
 
     tmux.send_keys %(seq 100 | #{FZF} --multi --reverse --preview-window 0 --preview 'env | grep ^FZF_ | sort > #{tempname}' --no-input --bind enter:show-input+refresh-preview,space:disable-search+refresh-preview), :Enter
     expected = {
+      FZF_DIRECTION: 'down',
       FZF_TOTAL_COUNT: '100',
       FZF_MATCH_COUNT: '100',
       FZF_SELECT_COUNT: '0',
@@ -1970,7 +2005,7 @@ class TestCore < TestInteractive
       end
     end
     elapsed = Time.now - time
-    assert elapsed < 2
+    assert_operator elapsed, :<, 2
   end
 
   def test_bg_cancel
@@ -1983,7 +2018,7 @@ class TestCore < TestInteractive
     tmux.until { assert_equal 2, it.match_count }
     tmux.send_keys :Space
     tmux.until { |lines| assert lines.any_include?('[0]') }
-    sleep 2
+    sleep(2)
     tmux.until do |lines|
       assert lines.any_include?('[0]')
       refute lines.any_include?('[1]')
